# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RuleSchemaFormula(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'anomaly_detection': 'RuleSchemaFormulaAnomalydetection',
        'count': 'RuleSchemaFormulaCount',
        'dynamic_threshold': 'RuleSchemaFormulaDynamicthreshold',
        'eval': 'RuleSchemaFormulaEval',
        'max': 'RuleSchemaFormulaMax',
        'mean': 'RuleSchemaFormulaMean',
        'concatenate': 'RuleSchemaFormulaConcatenate',
        'microburst': 'RuleSchemaFormulaMicroburst',
        'min': 'RuleSchemaFormulaMin',
        'outlier_detection': 'RuleSchemaFormulaOutlierdetection',
        'predict': 'RuleSchemaFormulaPredict',
        'rate_of_change': 'RuleSchemaFormulaRateofchange',
        'elapsed_time': 'RuleSchemaFormulaElapsedtime',
        'value_difference': 'RuleSchemaFormulaValuedifference',
        'stddev': 'RuleSchemaFormulaStddev',
        'sum': 'RuleSchemaFormulaSum',
        'user_defined_function': 'RuleSchemaFormulaUserdefinedfunction'
    }

    attribute_map = {
        'anomaly_detection': 'anomaly-detection',
        'count': 'count',
        'dynamic_threshold': 'dynamic-threshold',
        'eval': 'eval',
        'max': 'max',
        'mean': 'mean',
        'concatenate': 'concatenate',
        'microburst': 'microburst',
        'min': 'min',
        'outlier_detection': 'outlier-detection',
        'predict': 'predict',
        'rate_of_change': 'rate-of-change',
        'elapsed_time': 'elapsed-time',
        'value_difference': 'value-difference',
        'stddev': 'stddev',
        'sum': 'sum',
        'user_defined_function': 'user-defined-function'
    }

    def __init__(self, anomaly_detection=None, count=None, dynamic_threshold=None, eval=None, max=None, mean=None, concatenate=None, microburst=None, min=None, outlier_detection=None, predict=None, rate_of_change=None, elapsed_time=None, value_difference=None, stddev=None, sum=None, user_defined_function=None):  # noqa: E501
        """RuleSchemaFormula - a model defined in Swagger"""  # noqa: E501

        self._anomaly_detection = None
        self._count = None
        self._dynamic_threshold = None
        self._eval = None
        self._max = None
        self._mean = None
        self._concatenate = None
        self._microburst = None
        self._min = None
        self._outlier_detection = None
        self._predict = None
        self._rate_of_change = None
        self._elapsed_time = None
        self._value_difference = None
        self._stddev = None
        self._sum = None
        self._user_defined_function = None
        self.discriminator = None

        if anomaly_detection is not None:
            self.anomaly_detection = anomaly_detection
        if count is not None:
            self.count = count
        if dynamic_threshold is not None:
            self.dynamic_threshold = dynamic_threshold
        if eval is not None:
            self.eval = eval
        if max is not None:
            self.max = max
        if mean is not None:
            self.mean = mean
        if concatenate is not None:
            self.concatenate = concatenate
        if microburst is not None:
            self.microburst = microburst
        if min is not None:
            self.min = min
        if outlier_detection is not None:
            self.outlier_detection = outlier_detection
        if predict is not None:
            self.predict = predict
        if rate_of_change is not None:
            self.rate_of_change = rate_of_change
        if elapsed_time is not None:
            self.elapsed_time = elapsed_time
        if value_difference is not None:
            self.value_difference = value_difference
        if stddev is not None:
            self.stddev = stddev
        if sum is not None:
            self.sum = sum
        if user_defined_function is not None:
            self.user_defined_function = user_defined_function

    @property
    def anomaly_detection(self):
        """Gets the anomaly_detection of this RuleSchemaFormula.  # noqa: E501


        :return: The anomaly_detection of this RuleSchemaFormula.  # noqa: E501
        :rtype: RuleSchemaFormulaAnomalydetection
        """
        return self._anomaly_detection

    @anomaly_detection.setter
    def anomaly_detection(self, anomaly_detection):
        """Sets the anomaly_detection of this RuleSchemaFormula.


        :param anomaly_detection: The anomaly_detection of this RuleSchemaFormula.  # noqa: E501
        :type: RuleSchemaFormulaAnomalydetection
        """

        self._anomaly_detection = anomaly_detection

    @property
    def count(self):
        """Gets the count of this RuleSchemaFormula.  # noqa: E501


        :return: The count of this RuleSchemaFormula.  # noqa: E501
        :rtype: RuleSchemaFormulaCount
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this RuleSchemaFormula.


        :param count: The count of this RuleSchemaFormula.  # noqa: E501
        :type: RuleSchemaFormulaCount
        """

        self._count = count

    @property
    def dynamic_threshold(self):
        """Gets the dynamic_threshold of this RuleSchemaFormula.  # noqa: E501


        :return: The dynamic_threshold of this RuleSchemaFormula.  # noqa: E501
        :rtype: RuleSchemaFormulaDynamicthreshold
        """
        return self._dynamic_threshold

    @dynamic_threshold.setter
    def dynamic_threshold(self, dynamic_threshold):
        """Sets the dynamic_threshold of this RuleSchemaFormula.


        :param dynamic_threshold: The dynamic_threshold of this RuleSchemaFormula.  # noqa: E501
        :type: RuleSchemaFormulaDynamicthreshold
        """

        self._dynamic_threshold = dynamic_threshold

    @property
    def eval(self):
        """Gets the eval of this RuleSchemaFormula.  # noqa: E501


        :return: The eval of this RuleSchemaFormula.  # noqa: E501
        :rtype: RuleSchemaFormulaEval
        """
        return self._eval

    @eval.setter
    def eval(self, eval):
        """Sets the eval of this RuleSchemaFormula.


        :param eval: The eval of this RuleSchemaFormula.  # noqa: E501
        :type: RuleSchemaFormulaEval
        """

        self._eval = eval

    @property
    def max(self):
        """Gets the max of this RuleSchemaFormula.  # noqa: E501


        :return: The max of this RuleSchemaFormula.  # noqa: E501
        :rtype: RuleSchemaFormulaMax
        """
        return self._max

    @max.setter
    def max(self, max):
        """Sets the max of this RuleSchemaFormula.


        :param max: The max of this RuleSchemaFormula.  # noqa: E501
        :type: RuleSchemaFormulaMax
        """

        self._max = max

    @property
    def mean(self):
        """Gets the mean of this RuleSchemaFormula.  # noqa: E501


        :return: The mean of this RuleSchemaFormula.  # noqa: E501
        :rtype: RuleSchemaFormulaMean
        """
        return self._mean

    @mean.setter
    def mean(self, mean):
        """Sets the mean of this RuleSchemaFormula.


        :param mean: The mean of this RuleSchemaFormula.  # noqa: E501
        :type: RuleSchemaFormulaMean
        """

        self._mean = mean

    @property
    def concatenate(self):
        """Gets the concatenate of this RuleSchemaFormula.  # noqa: E501


        :return: The concatenate of this RuleSchemaFormula.  # noqa: E501
        :rtype: RuleSchemaFormulaConcatenate
        """
        return self._concatenate

    @concatenate.setter
    def concatenate(self, concatenate):
        """Sets the concatenate of this RuleSchemaFormula.


        :param concatenate: The concatenate of this RuleSchemaFormula.  # noqa: E501
        :type: RuleSchemaFormulaConcatenate
        """

        self._concatenate = concatenate

    @property
    def microburst(self):
        """Gets the microburst of this RuleSchemaFormula.  # noqa: E501


        :return: The microburst of this RuleSchemaFormula.  # noqa: E501
        :rtype: RuleSchemaFormulaMicroburst
        """
        return self._microburst

    @microburst.setter
    def microburst(self, microburst):
        """Sets the microburst of this RuleSchemaFormula.


        :param microburst: The microburst of this RuleSchemaFormula.  # noqa: E501
        :type: RuleSchemaFormulaMicroburst
        """

        self._microburst = microburst

    @property
    def min(self):
        """Gets the min of this RuleSchemaFormula.  # noqa: E501


        :return: The min of this RuleSchemaFormula.  # noqa: E501
        :rtype: RuleSchemaFormulaMin
        """
        return self._min

    @min.setter
    def min(self, min):
        """Sets the min of this RuleSchemaFormula.


        :param min: The min of this RuleSchemaFormula.  # noqa: E501
        :type: RuleSchemaFormulaMin
        """

        self._min = min

    @property
    def outlier_detection(self):
        """Gets the outlier_detection of this RuleSchemaFormula.  # noqa: E501


        :return: The outlier_detection of this RuleSchemaFormula.  # noqa: E501
        :rtype: RuleSchemaFormulaOutlierdetection
        """
        return self._outlier_detection

    @outlier_detection.setter
    def outlier_detection(self, outlier_detection):
        """Sets the outlier_detection of this RuleSchemaFormula.


        :param outlier_detection: The outlier_detection of this RuleSchemaFormula.  # noqa: E501
        :type: RuleSchemaFormulaOutlierdetection
        """

        self._outlier_detection = outlier_detection

    @property
    def predict(self):
        """Gets the predict of this RuleSchemaFormula.  # noqa: E501


        :return: The predict of this RuleSchemaFormula.  # noqa: E501
        :rtype: RuleSchemaFormulaPredict
        """
        return self._predict

    @predict.setter
    def predict(self, predict):
        """Sets the predict of this RuleSchemaFormula.


        :param predict: The predict of this RuleSchemaFormula.  # noqa: E501
        :type: RuleSchemaFormulaPredict
        """

        self._predict = predict

    @property
    def rate_of_change(self):
        """Gets the rate_of_change of this RuleSchemaFormula.  # noqa: E501


        :return: The rate_of_change of this RuleSchemaFormula.  # noqa: E501
        :rtype: RuleSchemaFormulaRateofchange
        """
        return self._rate_of_change

    @rate_of_change.setter
    def rate_of_change(self, rate_of_change):
        """Sets the rate_of_change of this RuleSchemaFormula.


        :param rate_of_change: The rate_of_change of this RuleSchemaFormula.  # noqa: E501
        :type: RuleSchemaFormulaRateofchange
        """

        self._rate_of_change = rate_of_change

    @property
    def elapsed_time(self):
        """Gets the elapsed_time of this RuleSchemaFormula.  # noqa: E501


        :return: The elapsed_time of this RuleSchemaFormula.  # noqa: E501
        :rtype: RuleSchemaFormulaElapsedtime
        """
        return self._elapsed_time

    @elapsed_time.setter
    def elapsed_time(self, elapsed_time):
        """Sets the elapsed_time of this RuleSchemaFormula.


        :param elapsed_time: The elapsed_time of this RuleSchemaFormula.  # noqa: E501
        :type: RuleSchemaFormulaElapsedtime
        """

        self._elapsed_time = elapsed_time

    @property
    def value_difference(self):
        """Gets the value_difference of this RuleSchemaFormula.  # noqa: E501


        :return: The value_difference of this RuleSchemaFormula.  # noqa: E501
        :rtype: RuleSchemaFormulaValuedifference
        """
        return self._value_difference

    @value_difference.setter
    def value_difference(self, value_difference):
        """Sets the value_difference of this RuleSchemaFormula.


        :param value_difference: The value_difference of this RuleSchemaFormula.  # noqa: E501
        :type: RuleSchemaFormulaValuedifference
        """

        self._value_difference = value_difference

    @property
    def stddev(self):
        """Gets the stddev of this RuleSchemaFormula.  # noqa: E501


        :return: The stddev of this RuleSchemaFormula.  # noqa: E501
        :rtype: RuleSchemaFormulaStddev
        """
        return self._stddev

    @stddev.setter
    def stddev(self, stddev):
        """Sets the stddev of this RuleSchemaFormula.


        :param stddev: The stddev of this RuleSchemaFormula.  # noqa: E501
        :type: RuleSchemaFormulaStddev
        """

        self._stddev = stddev

    @property
    def sum(self):
        """Gets the sum of this RuleSchemaFormula.  # noqa: E501


        :return: The sum of this RuleSchemaFormula.  # noqa: E501
        :rtype: RuleSchemaFormulaSum
        """
        return self._sum

    @sum.setter
    def sum(self, sum):
        """Sets the sum of this RuleSchemaFormula.


        :param sum: The sum of this RuleSchemaFormula.  # noqa: E501
        :type: RuleSchemaFormulaSum
        """

        self._sum = sum

    @property
    def user_defined_function(self):
        """Gets the user_defined_function of this RuleSchemaFormula.  # noqa: E501


        :return: The user_defined_function of this RuleSchemaFormula.  # noqa: E501
        :rtype: RuleSchemaFormulaUserdefinedfunction
        """
        return self._user_defined_function

    @user_defined_function.setter
    def user_defined_function(self, user_defined_function):
        """Sets the user_defined_function of this RuleSchemaFormula.


        :param user_defined_function: The user_defined_function of this RuleSchemaFormula.  # noqa: E501
        :type: RuleSchemaFormulaUserdefinedfunction
        """

        self._user_defined_function = user_defined_function

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RuleSchemaFormula, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RuleSchemaFormula):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from jnpr.healthbot.modules.profiles import Security

from jnpr.healthbot.swagger.models.notification_schema import NotificationSchema
from jnpr.healthbot.swagger.models.retention_policy_schema import RetentionPolicySchema
from jnpr.healthbot.swagger.models.scheduler_schema import SchedulerSchema
from jnpr.healthbot.swagger.models.report_schema import ReportSchema
from jnpr.healthbot.swagger.models.destination_schema import DestinationSchema
from jnpr.healthbot.swagger.api.license_api import LicenseApi
from jnpr.healthbot.exception import SchemaError, NotFoundError

from jnpr.healthbot.modules import BaseModule
# from jnpr.healthbot import AutoGenClass

import logging
logger = logging.getLogger(__file__)


class Settings(object):

    def __init__(self, hbot):
        """
        :param object hbot: :class:`jnpr.healthbot.HealthBotClient` client instance
        """

        self._hbot = hbot
        self.notification = Notification(hbot)
        self.retention_policy = RetentionPolicy(hbot)
        self.scheduler = Scheduler(hbot)
        self.report = Report(hbot)
        self.destination = Destination(hbot)
        self.security = Security(hbot)
        self.license = LicenseKeyManagement(hbot)


class Notification(BaseModule):

    def __init__(self, hbot):
        """
        :param object hbot: :class:`jnpr.healthbot.HealthBotClient` client instance
        """
        super().__init__(hbot)

    def get(self, notification_name: str = None, uncommitted: bool = True):
        """
        Get `NotificationSchema(s) <jnpr.healthbot.swagger.models.html#notificationschema>`_ for
        given notification name or list for all

        :param notification_name: ID of notification-name
        :param bool uncommitted: True includes fetches uncommitted changes,
            False restricts data set to only committed changes

        Example:
        ::

                from jnpr.healthbot import HealthBotClient

                with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                    print(hb.settings.notification.get('xyz')

        :return: `NotificationSchema(s) <jnpr.healthbot.swagger.models.html#notificationschema>`_
        """
        if notification_name is not None:
            notification_url = self.hbot.urlfor.notification(notification_name)
            if uncommitted:
                notification_url += self.hbot.apiopt_candidate
            response = self.api.get(notification_url)
            if response.status_code != 200:
                logger.error(response.text)
            response.raise_for_status()
            return self.hbot._create_schema(response, NotificationSchema)
        else:
            notifications_url = self.hbot.urlfor.notifications()
            if uncommitted:
                notifications_url += self.hbot.apiopt_candidate
            response = self.api.get(notifications_url)
            response_json = response.json()
            if response.status_code != 200:
                logger.error(response.text)
                raise NotFoundError(response_json)
            existing_notifications = response_json['notification']
            notification_list = []
            for notification in existing_notifications:
                obj = self.hbot._create_schema(
                    notification, NotificationSchema)
                notification_list.append(obj)

            return notification_list

    def add(self, schema: NotificationSchema = None, **kwargs):
        """
        Add notification to HealthBot

        :param object schema: `NotificationSchema <jnpr.healthbot.swagger.models.html#notificationschema>`_
        :param object kwargs: key values, which can be used to create
            NotificationSchema
            Check `NotificationSchema <jnpr.healthbot.swagger.models.html#notificationschema>`_
            for details about which all keys can be used

        Example:
        ::

            from jnpr.healthbot import HealthBotClient
            from jnpr.healthbot import NotificationSchema, NotificationSchemaSlack

            with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                ns = NotificationSchema(notification_name='HbEZ-notification')
                ns.description = "example of adding notification via API"
                ns.slack = NotificationSchemaSlack(channel="HbEZ", url='http://testing')
                hb.settings.notification.add(ns)

        :returns: True when OK

        """
        if schema is None:
            schema = NotificationSchema(**kwargs)
        payload = self.hbot._create_payload(schema)
        notification_url = self.hbot.urlfor.notification(
            payload['notification-name'])
        response = self.api.post(notification_url, json=payload)
        if response.status_code != 200:
            logger.error(response.text)
        response.raise_for_status()
        return True

    def delete(self, notification_name: str):
        """
        Remove notification from settings

        :param str notification_name: The name of the notification to be deleted

        Example:
        ::
            hb.settings.notification.delete('xyz')
            hb.commit()

        :returns: True when OK
        """

        notification_url = self.hbot.urlfor.notification(notification_name)
        response = self.api.delete(notification_url)
        if response.status_code != 204:
            logger.error(response.text)
        response.raise_for_status()

        return True

    def update(self, schema: NotificationSchema = None, **kwargs):
        """
        Update `NotificationSchema <jnpr.healthbot.swagger.models.html#notificationschema>`_ for
        given NotificationSchema schema

        Passing Schema invoke `put` and kwargs `post`

        :param obj schema: `NotificationSchema <jnpr.healthbot.swagger.models.html#notificationschema>`_
        :param object kwargs: key values, which can be used to create
            RetentionPolicySchema
            Check `NotificationSchema <jnpr.healthbot.swagger.models.html#notificationschema>`_
            for details about which all keys can be used

        Example:
        ::

            from jnpr.healthbot import HealthBotClient
            with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                schemaObj = hb.settings.notification.get('xyz')
                schemaObj.description = 'changed description'
                hb.settings.notification.update(schemaObj)

        :returns: True when OK
        """
        if schema is None:
            schema = NotificationSchema(**kwargs)
            call = self.api.post
        else:
            if not isinstance(schema, NotificationSchema):
                raise SchemaError(NotificationSchema)
            call = self.api.put
        payload = self.hbot._create_payload(schema)
        name = schema.notification_name
        notification_url = self.hbot.urlfor.notification(name)
        response = call(notification_url, json=payload)
        if response.status_code != 200:
            logger.error(response.text)
        response.raise_for_status()
        return True


class RetentionPolicy(BaseModule):

    def __init__(self, hbot):
        """
        :param object hbot: :class:`jnpr.healthbot.HealthBotClient` client instance
        """
        super().__init__(hbot)

    def get(
            self,
            retention_policy_name: str = None,
            uncommitted=True):
        """
        Get `RetentionPolicySchema(s) <jnpr.healthbot.swagger.models.html#retentionpolicyschema>`_ for
        given retention policy name or list for all

        :param retention_policy_name: ID of retention-policy-name
        :param bool uncommitted: True includes fetches uncommitted changes,
            False restricts data set to only committed changes

        Example:
        ::
                from jnpr.healthbot import HealthBotClient

                with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                    print(hb.settings.retention_policy.get('xyz')

                    # for all
                    print(hb.settings.retention_policy.get()

        :return: `RetentionPolicySchema(s) <jnpr.healthbot.swagger.models.html#retentionpolicyschema>`_
        """
        if retention_policy_name is not None:
            retention_policy_url = self.hbot.urlfor.retention_policy(
                retention_policy_name)
            if uncommitted:
                retention_policy_url += self.hbot.apiopt_candidate
            response = self.api.get(retention_policy_url)
            if response.status_code != 200:
                logger.error(response.text)
            response.raise_for_status()
            return self.hbot._create_schema(response, RetentionPolicySchema)
        else:
            notifications_url = self.hbot.urlfor.retention_policies()
            if uncommitted:
                notifications_url += self.hbot.apiopt_candidate
            response = self.api.get(notifications_url)
            response_json = response.json()
            if response.status_code != 200:
                logger.error(response.text)
                raise NotFoundError(response_json)
            existing_retention_policies = response_json['retention-policy']
            existing_retention_policies_list = []
            for retention_policy in existing_retention_policies:
                obj = self.hbot._create_schema(
                    retention_policy, RetentionPolicySchema)
                existing_retention_policies_list.append(obj)

            return existing_retention_policies_list

    def add(
            self,
            schema: RetentionPolicySchema = None,
            **kwargs):
        """
        Add notification to HealthBot

        :param object schema: `RetentionPolicySchema <jnpr.healthbot.swagger.models.html#retentionpolicyschema>`_
        :param object kwargs: key values, which can be used to create
            RetentionPolicySchema
            Check `RetentionPolicySchema <jnpr.healthbot.swagger.models.html#retentionpolicyschema>`_
            for details about which all keys can be used

        Example:
        ::

            from jnpr.healthbot import HealthBotClient
            from jnpr.healthbot import RetentionPolicySchema

            with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                rps = RetentionPolicySchema(retention_policy_name='HbEZ-rentention-policy')
                hb.settings.retention_policy.add(rps)

        :returns: True when OK

        """
        if schema is None:
            schema = RetentionPolicySchema(**kwargs)
        payload = self.hbot._create_payload(schema)
        retention_policy_url = self.hbot.urlfor.retention_policy(
            payload['retention-policy-name'])
        response = self.api.post(retention_policy_url, json=payload)
        if response.status_code != 200:
            logger.error(response.text)
        response.raise_for_status()
        return True

    def delete(self, retention_policy_name: str):
        """
        Remove notification from settings

        :param str retention_policy_name: The name of the retention policy to be deleted

        Example:
        ::
            hb.settings.retention_policy.delete('xyz')
            hb.commit()

        :returns: True when OK
        """

        retention_policy_url = self.hbot.urlfor.retention_policy(
            retention_policy_name)
        response = self.api.delete(retention_policy_url)
        if response.status_code != 200:
            logger.error(response.text)
        response.raise_for_status()

        return True

    def update(self, schema: RetentionPolicySchema = None, **kwargs):
        """
        Update `RetentionPolicySchema <jnpr.healthbot.swagger.models.html#retentionpolicyschema>`_ for
        given RetentionPolicySchema schema

        Passing Schema invoke `put` and kwargs `post`

        :param obj schema: `RetentionPolicySchema <jnpr.healthbot.swagger.models.html#retentionpolicyschema>`_
        :param object kwargs: key values, which can be used to create
            RetentionPolicySchema
            Check `RetentionPolicySchema <jnpr.healthbot.swagger.models.html#retentionpolicyschema>`_
            for details about which all keys can be used

        Example:
        ::

            from jnpr.healthbot import HealthBotClient

            with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                schemaObj = hb.settings.retention_policy.get('xyz')
                schemaObj.description = 'changed description'
                hb.settings.retention_policy.update(schemaObj)

        :returns: True when OK
        """
        if schema is None:
            schema = RetentionPolicySchema(**kwargs)
            call = self.api.post
        else:
            if not isinstance(schema, RetentionPolicySchema):
                raise SchemaError(RetentionPolicySchema)
            call = self.api.put
        payload = self.hbot._create_payload(schema)
        name = schema.retention_policy_name
        retention_policy_url = self.hbot.urlfor.retention_policy(name)
        response = call(retention_policy_url, json=payload)
        if response.status_code != 200:
            logger.error(response.text)
        response.raise_for_status()
        return True


class Scheduler(BaseModule):

    def __init__(self, hbot):
        """
        :param object hbot: :class:`jnpr.healthbot.HealthBotClient` client instance
        """
        super().__init__(hbot)

    def get(self, name: str = None, uncommitted: bool = True):
        """
        Get `SchedulerSchema(s) <jnpr.healthbot.swagger.models.html#schedulerschema>`_ for
        given scheduler name or list for all

        :param name: scheduler name
        :param bool uncommitted: True includes fetches uncommitted changes,
            False restricts data set to only committed changes

        Example:
        ::
                from jnpr.healthbot import HealthBotClient

                with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                    print(hb.settings.scheduler.get('xyz')

                    # for all
                    print(hb.settings.scheduler.get()

        :return: `SchedulerSchema(s) <jnpr.healthbot.swagger.models.html#schedulerschema>`_
        """
        if name is not None:
            scheduler_url = self.hbot.urlfor.scheduler(name)
            if uncommitted:
                scheduler_url += self.hbot.apiopt_candidate
            response = self.api.get(scheduler_url)
            if response.status_code != 200:
                logger.error(response.text)
            response.raise_for_status()
            return self.hbot._create_schema(response, SchedulerSchema)
        else:
            schedulers_url = self.hbot.urlfor.schedulers()
            if uncommitted:
                schedulers_url += self.hbot.apiopt_candidate
            response = self.api.get(schedulers_url)
            response_json = response.json()
            if response.status_code != 200:
                logger.error(response.text)
                raise NotFoundError(response_json)
            existing_schedulers = response_json['scheduler']
            existing_schedulers_list = []
            for scheduler in existing_schedulers:
                obj = self.hbot._create_schema(scheduler, SchedulerSchema)
                existing_schedulers_list.append(obj)

            return existing_schedulers_list

    def add(self, schema: SchedulerSchema = None, **kwargs):
        """
        Add scheduler to HealthBot

        :param object schema: `SchedulerSchema <jnpr.healthbot.swagger.models.html#schedulerschema>`_
        :param object kwargs: key values, which can be used to create
            SchedulerSchema
            Check `SchedulerSchema <jnpr.healthbot.swagger.models.html#schedulerschema>`_
            for details about which all keys can be used

        Example:
        ::

            from jnpr.healthbot import HealthBotClient
            from jnpr.healthbot import SchedulerSchema

            with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                sc = SchedulerSchema(name='HbEZ', repeat={'every': 'week'},
                        start_time="2019-07-22T05:32:23Z")
                hb.settings.scheduler.add(sc)

        :returns: True when OK

        """
        if schema is None:
            schema = SchedulerSchema(**kwargs)
        payload = self.hbot._create_payload(schema)
        scheduler_url = self.hbot.urlfor.scheduler(payload['name'])
        response = self.api.post(scheduler_url, json=payload)
        if response.status_code != 200:
            logger.error(response.text)
        response.raise_for_status()
        return True

    def delete(self, name: str):
        """
        Remove notification from settings

        :param str name: The name of the scheduler to be deleted

        Example:
        ::
            hb.settings.scheduler.delete('xyz')
            hb.commit()

        :returns: True when OK
        """

        scheduler_url = self.hbot.urlfor.scheduler(name)
        response = self.api.delete(scheduler_url)
        if response.status_code != 200:
            logger.error(response.text)
        response.raise_for_status()

        return True

    def update(self, schema: SchedulerSchema = None, **kwargs):
        """
        Update `SchedulerSchema <jnpr.healthbot.swagger.models.html#schedulerschema>`_ for
        given scheduler schema

        Passing Schema invoke `put` and kwargs `post`

        :param obj schema: `SchedulerSchema <jnpr.healthbot.swagger.models.html#schedulerschema>`_
        :param object kwargs: key values, which can be used to create
            SchedulerSchema
            Check `SchedulerSchema <jnpr.healthbot.swagger.models.html#schedulerschema>`_
            for details about which all keys can be used

        Example:
        ::

            from jnpr.healthbot import HealthBotClient
            with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                schemaObj = hb.settings.scheduler.get('xyz')
                schemaObj.description = 'changed description'
                hb.settings.scheduler.update(schemaObj)

        :returns: True when OK
        """
        if schema is None:
            schema = SchedulerSchema(**kwargs)
            call = self.api.post
        else:
            if not isinstance(schema, SchedulerSchema):
                raise SchemaError(SchedulerSchema)
            call = self.api.put
        payload = self.hbot._create_payload(schema)
        name = schema.name
        scheduler_url = self.hbot.urlfor.scheduler(name)
        response = call(scheduler_url, json=payload)
        if response.status_code != 200:
            logger.error(response.text)
        response.raise_for_status()
        return True


class Destination(BaseModule):

    def __init__(self, hbot):
        """
        :param object hbot: :class:`jnpr.healthbot.HealthBotClient` client instance
        """
        super().__init__(hbot)

    def get(self, name: str = None, uncommitted: bool = True):
        """
        Get `DestinationSchema(s) <jnpr.healthbot.swagger.models.html#destinationschema>`_ for
        given destination name or list for all

        :param name: destination ID
        :param bool uncommitted: True includes fetches uncommitted changes,
            False restricts data set to only committed changes

        Example:
        ::

                from jnpr.healthbot import HealthBotClient

                with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                    print(hb.settings.destination.get('xyz')

                    # for all
                    print(hb.settings.destination.get()

        :return: `DestinationSchema(s) <jnpr.healthbot.swagger.models.html#destinationschema>`_
        """
        if name is not None:
            destination_url = self.hbot.urlfor.destination(name)
            if uncommitted:
                destination_url += self.hbot.apiopt_candidate
            response = self.api.get(destination_url)
            if response.status_code != 200:
                logger.error(response.text)
            response.raise_for_status()
            return self.hbot._create_schema(response, DestinationSchema)
        else:
            destination_url = self.hbot.urlfor.destinations()
            if uncommitted:
                destination_url += self.hbot.apiopt_candidate
            response = self.api.get(destination_url)
            response_json = response.json()
            if response.status_code != 200:
                logger.error(response.text)
                raise NotFoundError(response_json)
            existing_destinations = response_json['destination']
            destinations_list = []
            for destination in existing_destinations:
                obj = self.hbot._create_schema(
                    destination, DestinationSchema)
                destinations_list.append(obj)

            return destinations_list

    def add(self, schema: DestinationSchema = None, **kwargs):
        """
        Add destination to HealthBot

        :param object schema: `DestinationSchema <jnpr.healthbot.swagger.models.html#destinationschema>`_
        :param object kwargs: key values, which can be used to create
            DestinationSchema
            Check `DestinationSchema <jnpr.healthbot.swagger.models.html#destinationschema>`_
            for details about which all keys can be used

        Example:
        ::

            from jnpr.healthbot import HealthBotClient
            from jnpr.healthbot import DestinationSchema

            with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                ds = DestinationSchema(name='HbEZ-destination')
                hb.settings.destination.add(ds)

        :returns: True when OK

        """
        if schema is None:
            schema = DestinationSchema(**kwargs)
        payload = self.hbot._create_payload(schema)
        destination_url = self.hbot.urlfor.destination(payload['name'])
        response = self.api.post(destination_url, json=payload)
        if response.status_code != 200:
            logger.error(response.text)
        response.raise_for_status()
        return True

    def delete(self, name: str):
        """
        Remove destination from settings

        :param str name: The ID name of the destination to be deleted

        Example:
        ::
            hb.settings.destination.delete('xyz')
            hb.commit()

        :returns: True when OK
        """

        destinations_url = self.hbot.urlfor.destination(name)
        response = self.api.delete(destinations_url)
        if response.status_code != 200:
            logger.error(response.text)
        response.raise_for_status()

        return True

    def update(self, schema: DestinationSchema = None, **kwargs):
        """
        Update `DestinationSchema <jnpr.healthbot.swagger.models.html#destinationschema>`_ for
        given destination schema

        Passing Schema invoke `put` and kwargs `post`

        :param obj schema: `DestinationSchema <jnpr.healthbot.swagger.models.html#destinationschema>`_
        :param object kwargs: key values, which can be used to create
            DestinationSchema
            Check `DestinationSchema <jnpr.healthbot.swagger.models.html#destinationschema>`_
            for details about which all keys can be used

        Example:
        ::

            from jnpr.healthbot import HealthBotClient
            with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                schemaObj = hb.settings.destination.get('xyz')
                schemaObj.description = 'changed description'
                hb.settings.destination.update(schemaObj)

        :returns: True when OK
        """
        if schema is None:
            schema = DestinationSchema(**kwargs)
            call = self.api.post
        else:
            if not isinstance(schema, DestinationSchema):
                raise SchemaError(DestinationSchema)
            call = self.api.put
        payload = self.hbot._create_payload(schema)
        name = schema.name
        destination_url = self.hbot.urlfor.destination(name)
        response = call(destination_url, json=payload)
        if response.status_code != 200:
            logger.error(response.text)
        response.raise_for_status()
        return True


class Report(BaseModule):

    def __init__(self, hbot):
        """
        :param object hbot: :class:`jnpr.healthbot.HealthBotClient` client instance
        """
        super().__init__(hbot)

    def get(self, name: str = None, uncommitted: bool = True):
        """
        Get `ReportSchema(s) <jnpr.healthbot.swagger.models.html#reportschema>`_ for
        given report name or list for all

        :param name: report ID
        :param bool uncommitted: True includes fetches uncommitted changes,
            False restricts data set to only committed changes

        Example:
        ::

                from jnpr.healthbot import HealthBotClient

                with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                    print(hb.settings.report.get('xyz')

                    # for all
                    print(hb.settings.report.get()

        :return: `ReportSchema(s) <jnpr.healthbot.swagger.models.html#reportschema>`_
        """
        if name is not None:
            report_url = self.hbot.urlfor.report(name)
            if uncommitted:
                report_url += self.hbot.apiopt_candidate
            response = self.api.get(report_url)
            if response.status_code != 200:
                logger.error(response.text)
            response.raise_for_status()
            return self.hbot._create_schema(
                response, ReportSchema)
        else:
            reports_url = self.hbot.urlfor.reports()
            if uncommitted:
                reports_url += self.hbot.apiopt_candidate
            response = self.api.get(reports_url)
            response_json = response.json()
            if response.status_code != 200:
                logger.error(response.text)
                raise NotFoundError(response_json)
            existing_reports = response_json['report']
            reports_list = []
            for report in existing_reports:
                obj = self.hbot._create_schema(report, ReportSchema)
                reports_list.append(obj)

            return reports_list

    def add(self, schema: ReportSchema = None, **kwargs):
        """
        Add report to HealthBot

        :param object schema: `ReportSchema <jnpr.healthbot.swagger.models.html#reportschema>`_
        :param object kwargs: key values, which can be used to create
            ReportSchema
            Check `ReportSchema <jnpr.healthbot.swagger.models.html#reportschema>`_
            for details about which all keys can be used

        Example:
        ::

            from jnpr.healthbot import HealthBotClient
            from jnpr.healthbot import ReportSchema

            with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:

                from jnpr.healthbot import SchedulerSchema
                sc = SchedulerSchema(name='HbEZ-schedule', repeat={'every': 'week'},
                                start_time="2019-07-22T05:32:23Z")
                hb.settings.scheduler.add(sc)

                from jnpr.healthbot import DestinationSchema
                ds = DestinationSchema(name='HbEZ-destination',
                                email={'id': 'nitinkr@juniper.net'})
                hb.settings.destination.add(ds)

                from jnpr.healthbot import ReportSchema
                rs = ReportSchema(name="HbEZ-report", destination=['HbEZ-destination'],
                                format="html", schedule=["HbEZ-schedule"])
                hb.settings.report.add(rs)

        :returns: True when OK

        """
        if schema is None:
            schema = ReportSchema(**kwargs)
        payload = self.hbot._create_payload(schema)
        report_url = self.hbot.urlfor.report(payload['name'])
        response = self.api.post(report_url, json=payload)
        if response.status_code != 200:
            logger.error(response.text)
        response.raise_for_status()
        return True

    def delete(self, name: str):
        """
        Remove report from settings

        :param str name: The name of the report to be deleted

        Example:
        ::

            hb.settings.report.delete('xyz')
            hb.commit()

        :returns: True when OK
        """

        report_url = self.hbot.urlfor.report(name)
        response = self.api.delete(report_url)
        if response.status_code != 200:
            logger.error(response.text)
        response.raise_for_status()

        return True

    def update(self, schema: ReportSchema = None, **kwargs):
        """
        Update `ReportSchema <jnpr.healthbot.swagger.models.html#reportschema>`_ for
        given report schema

        Passing Schema invoke `put` and kwargs `post`

        :param obj schema: `ReportSchema <jnpr.healthbot.swagger.models.html#reportschema>`_
        :param object kwargs: key values, which can be used to create
            ReportSchema
            Check `ReportSchema <jnpr.healthbot.swagger.models.html#reportschema>`_
            for details about which all keys can be used

        Example:
        ::

            from jnpr.healthbot import HealthBotClient
            with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                schemaObj = hb.settings.report.get('xyz')
                schemaObj.description = 'changed description'
                hb.settings.report.update(schemaObj)

        :returns: True when OK
        """
        if schema is None:
            schema = ReportSchema(**kwargs)
            call = self.api.post
        else:
            if not isinstance(schema, ReportSchema):
                raise SchemaError(ReportSchema)
            call = self.api.put
        payload = self.hbot._create_payload(schema)
        name = schema.name
        report_url = self.hbot.urlfor.report(name)
        response = call(report_url, json=payload)
        if response.status_code != 200:
            logger.error(response.text)
        response.raise_for_status()
        return True


class LicenseKeyManagement(BaseModule):

    def __init__(self, hbot):
        """
        :param object hbot: :class:`jnpr.healthbot.HealthBotClient` client instance
        """
        super().__init__(hbot)
        self._license_api = LicenseApi(hbot.api_client)

    def get_features(self):
        """
        Get `LicenseFeatureSchema(s) <jnpr.healthbot.swagger.models.html#licensefeatureschema>`_ for
        given license id or for all licence id

        :param license_id: License ID

        Example:
        ::

                from jnpr.healthbot import HealthBotClient

                with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                    print(hb.settings.license.get_features()

        :return: `LicenseFeatureSchema(s) <jnpr.healthbot.swagger.models.html#licensefeatureschema>`_

        """
        response = self._license_api.retrieve_iceberg_license_features_info(
            x_iam_token=self.authorization)
        return response.license_feature

    def get_ids(self):
        """
        List of all licence id

        Example:
        ::

                from jnpr.healthbot import HealthBotClient

                with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                    # print all existing licence ids
                    print(hb.settings.license.get()
        :return: `List of license ids`

        """
        return self._license_api.retrieve_iceberg_get_all_license_id(
            x_iam_token=self.authorization)

    def get(self, license_id: str = None):
        """
        Get `LicenseKeySchema(s) <jnpr.healthbot.swagger.models.html#licensekeyschema>`_ for
        given license id or for all licence id

        :param license_id: License ID

        Example:
        ::

                from jnpr.healthbot import HealthBotClient

                with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                    print(hb.settings.license.get()

                    # for given licence id
                    print(hb.settings.report.get('xxxxx')

        :return: `LicenseKeySchema(s) <jnpr.healthbot.swagger.models.html#licensekeyschema>`_
        """
        if license_id is not None:
            return self._license_api.retrieve_iceberg_license_key_contents_by_id(
                    license_id, x_iam_token=self.authorization)
        else:
            response = self._license_api.retrieve_iceberg_license_key_contents(
                x_iam_token=self.authorization)
            return response.license_key

    def add(self, license_file):
        """
        Add report to HealthBot

        :param path license_file: license file path

        Example:
        ::

            from jnpr.healthbot import HealthBotClient

            with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                hb.settings.license.add(license_file='/var/tmp/xyz')

        :returns: license_id if OK

        """
        response = self._license_api.create_iceberg_add_license_from_file(
            license_file, x_iam_token=self.authorization)
        return response.license_id

    def delete(self, license_id: str):
        """
        Remove report from settings

        :param str license_id: The license id be deleted

        Example:
        ::

            hb.settings.license.delete('xx-xxx-xxx-xxx-xx')

        :returns: True when OK
        """

        self._license_api.delete_iceberg_delete_license_by_id(
            license_id, x_iam_token=self.authorization)

        return True



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class IngestmappingSchemaIAgent(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'for_device_groups': 'list[str]',
        'use_plugin': 'IngestmappingSchemaIAgentUseplugin'
    }

    attribute_map = {
        'for_device_groups': 'for-device-groups',
        'use_plugin': 'use-plugin'
    }

    def __init__(self, for_device_groups=None, use_plugin=None):  # noqa: E501
        """IngestmappingSchemaIAgent - a model defined in Swagger"""  # noqa: E501

        self._for_device_groups = None
        self._use_plugin = None
        self.discriminator = None

        if for_device_groups is not None:
            self.for_device_groups = for_device_groups
        if use_plugin is not None:
            self.use_plugin = use_plugin

    @property
    def for_device_groups(self):
        """Gets the for_device_groups of this IngestmappingSchemaIAgent.  # noqa: E501


        :return: The for_device_groups of this IngestmappingSchemaIAgent.  # noqa: E501
        :rtype: list[str]
        """
        return self._for_device_groups

    @for_device_groups.setter
    def for_device_groups(self, for_device_groups):
        """Sets the for_device_groups of this IngestmappingSchemaIAgent.


        :param for_device_groups: The for_device_groups of this IngestmappingSchemaIAgent.  # noqa: E501
        :type: list[str]
        """

        self._for_device_groups = for_device_groups

    @property
    def use_plugin(self):
        """Gets the use_plugin of this IngestmappingSchemaIAgent.  # noqa: E501


        :return: The use_plugin of this IngestmappingSchemaIAgent.  # noqa: E501
        :rtype: IngestmappingSchemaIAgentUseplugin
        """
        return self._use_plugin

    @use_plugin.setter
    def use_plugin(self, use_plugin):
        """Sets the use_plugin of this IngestmappingSchemaIAgent.


        :param use_plugin: The use_plugin of this IngestmappingSchemaIAgent.  # noqa: E501
        :type: IngestmappingSchemaIAgentUseplugin
        """

        self._use_plugin = use_plugin

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(IngestmappingSchemaIAgent, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IngestmappingSchemaIAgent):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from jnpr.healthbot.swagger.api_client import ApiClient


class ServicesApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_services_device_groups_device_group_by_device_group_name(self, device_group_name, **kwargs):  # noqa: E501
        """Start a device-group's services.  # noqa: E501

        Start services of a device group. Use this to start stopped services.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_services_device_groups_device_group_by_device_group_name(device_group_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str device_group_name: Name of device group (required)
        :param str x_iam_token: authentication header object
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_services_device_groups_device_group_by_device_group_name_with_http_info(device_group_name, **kwargs)  # noqa: E501
        else:
            (data) = self.create_services_device_groups_device_group_by_device_group_name_with_http_info(device_group_name, **kwargs)  # noqa: E501
            return data

    def create_services_device_groups_device_group_by_device_group_name_with_http_info(self, device_group_name, **kwargs):  # noqa: E501
        """Start a device-group's services.  # noqa: E501

        Start services of a device group. Use this to start stopped services.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_services_device_groups_device_group_by_device_group_name_with_http_info(device_group_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str device_group_name: Name of device group (required)
        :param str x_iam_token: authentication header object
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['device_group_name', 'x_iam_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_services_device_groups_device_group_by_device_group_name" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'device_group_name' is set
        if ('device_group_name' not in params or
                params['device_group_name'] is None):
            raise ValueError("Missing the required parameter `device_group_name` when calling `create_services_device_groups_device_group_by_device_group_name`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'device_group_name' in params:
            path_params['device_group_name'] = params['device_group_name']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_iam_token' in params:
            header_params['x-iam-token'] = params['x_iam_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/octet-stream'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/config/services/device-group/{device_group_name}/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_services_network_group_by_network_group_name(self, network_group_name, **kwargs):  # noqa: E501
        """Start a network-group's services.  # noqa: E501

        Start services of a network group. Use this to start stopped services.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_services_network_group_by_network_group_name(network_group_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str network_group_name: Name of network group (required)
        :param str x_iam_token: authentication header object
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_services_network_group_by_network_group_name_with_http_info(network_group_name, **kwargs)  # noqa: E501
        else:
            (data) = self.create_services_network_group_by_network_group_name_with_http_info(network_group_name, **kwargs)  # noqa: E501
            return data

    def create_services_network_group_by_network_group_name_with_http_info(self, network_group_name, **kwargs):  # noqa: E501
        """Start a network-group's services.  # noqa: E501

        Start services of a network group. Use this to start stopped services.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_services_network_group_by_network_group_name_with_http_info(network_group_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str network_group_name: Name of network group (required)
        :param str x_iam_token: authentication header object
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['network_group_name', 'x_iam_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_services_network_group_by_network_group_name" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'network_group_name' is set
        if ('network_group_name' not in params or
                params['network_group_name'] is None):
            raise ValueError("Missing the required parameter `network_group_name` when calling `create_services_network_group_by_network_group_name`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'network_group_name' in params:
            path_params['network_group_name'] = params['network_group_name']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_iam_token' in params:
            header_params['x-iam-token'] = params['x_iam_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/octet-stream'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/config/services/network-group/{network_group_name}/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_services_device_groups_device_group_by_device_group_name(self, device_group_name, **kwargs):  # noqa: E501
        """Stop and remove a device-group's services.  # noqa: E501

        Stop and clean services of a device-group. This will remove all the services for a device-group, however, it  will not clean up the collected data.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_services_device_groups_device_group_by_device_group_name(device_group_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str device_group_name: Name of device group (required)
        :param str x_iam_token: authentication header object
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_services_device_groups_device_group_by_device_group_name_with_http_info(device_group_name, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_services_device_groups_device_group_by_device_group_name_with_http_info(device_group_name, **kwargs)  # noqa: E501
            return data

    def delete_services_device_groups_device_group_by_device_group_name_with_http_info(self, device_group_name, **kwargs):  # noqa: E501
        """Stop and remove a device-group's services.  # noqa: E501

        Stop and clean services of a device-group. This will remove all the services for a device-group, however, it  will not clean up the collected data.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_services_device_groups_device_group_by_device_group_name_with_http_info(device_group_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str device_group_name: Name of device group (required)
        :param str x_iam_token: authentication header object
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['device_group_name', 'x_iam_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_services_device_groups_device_group_by_device_group_name" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'device_group_name' is set
        if ('device_group_name' not in params or
                params['device_group_name'] is None):
            raise ValueError("Missing the required parameter `device_group_name` when calling `delete_services_device_groups_device_group_by_device_group_name`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'device_group_name' in params:
            path_params['device_group_name'] = params['device_group_name']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_iam_token' in params:
            header_params['x-iam-token'] = params['x_iam_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/octet-stream'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/config/services/device-group/{device_group_name}/', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_services_network_group_by_network_group_name(self, network_group_name, **kwargs):  # noqa: E501
        """Stop and remove a network-group's services.  # noqa: E501

        Stop and clean the services of a network group. This will remove all the services for a network-group, however, it will not clean up the collected data.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_services_network_group_by_network_group_name(network_group_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str network_group_name: Name of network group (required)
        :param str x_iam_token: authentication header object
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_services_network_group_by_network_group_name_with_http_info(network_group_name, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_services_network_group_by_network_group_name_with_http_info(network_group_name, **kwargs)  # noqa: E501
            return data

    def delete_services_network_group_by_network_group_name_with_http_info(self, network_group_name, **kwargs):  # noqa: E501
        """Stop and remove a network-group's services.  # noqa: E501

        Stop and clean the services of a network group. This will remove all the services for a network-group, however, it will not clean up the collected data.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_services_network_group_by_network_group_name_with_http_info(network_group_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str network_group_name: Name of network group (required)
        :param str x_iam_token: authentication header object
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['network_group_name', 'x_iam_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_services_network_group_by_network_group_name" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'network_group_name' is set
        if ('network_group_name' not in params or
                params['network_group_name'] is None):
            raise ValueError("Missing the required parameter `network_group_name` when calling `delete_services_network_group_by_network_group_name`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'network_group_name' in params:
            path_params['network_group_name'] = params['network_group_name']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_iam_token' in params:
            header_params['x-iam-token'] = params['x_iam_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/octet-stream'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/config/services/network-group/{network_group_name}/', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def retrieve_services_device_groups_device_group_device_group(self, **kwargs):  # noqa: E501
        """Get running `device-group-name`s.  # noqa: E501

        Get the list of `device-group-name`s of device-groups whose services are running.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_services_device_groups_device_group_device_group(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_iam_token: authentication header object
        :return: list[str]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.retrieve_services_device_groups_device_group_device_group_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.retrieve_services_device_groups_device_group_device_group_with_http_info(**kwargs)  # noqa: E501
            return data

    def retrieve_services_device_groups_device_group_device_group_with_http_info(self, **kwargs):  # noqa: E501
        """Get running `device-group-name`s.  # noqa: E501

        Get the list of `device-group-name`s of device-groups whose services are running.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_services_device_groups_device_group_device_group_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_iam_token: authentication header object
        :return: list[str]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_iam_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retrieve_services_device_groups_device_group_device_group" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_iam_token' in params:
            header_params['x-iam-token'] = params['x_iam_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/config/services/device-group/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[str]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def retrieve_services_network_group(self, **kwargs):  # noqa: E501
        """Get running `network-group-name`s  # noqa: E501

        Get the list of `network-group-name`s of network-groups whose services are running.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_services_network_group(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_iam_token: authentication header object
        :return: list[str]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.retrieve_services_network_group_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.retrieve_services_network_group_with_http_info(**kwargs)  # noqa: E501
            return data

    def retrieve_services_network_group_with_http_info(self, **kwargs):  # noqa: E501
        """Get running `network-group-name`s  # noqa: E501

        Get the list of `network-group-name`s of network-groups whose services are running.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_services_network_group_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_iam_token: authentication header object
        :return: list[str]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_iam_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retrieve_services_network_group" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_iam_token' in params:
            header_params['x-iam-token'] = params['x_iam_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/config/services/network-group/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[str]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class WorkflowSchemaStep(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cli_command': 'list[WorkflowCommandSchema]',
        'executable': 'list[WorkflowCommandSchema]',
        'netconf_command': 'list[WorkflowCommandSchema]',
        'notification': 'list[WorkflowNotificationSchema]',
        'condition': 'list[str]',
        'condition_description': 'str',
        'condition_type': 'str',
        'dependencies': 'list[str]',
        'description': 'str',
        'input': 'list[WorkflowSchemaInput]',
        'output': 'list[WorkflowSchemaOutput]',
        'step_name': 'str',
        'suspend': 'WorkflowSchemaSuspend',
        'task': 'WorkflowSchemaTask',
        'workflow': 'WorkflowSchemaWorkflow'
    }

    attribute_map = {
        'cli_command': 'cli-command',
        'executable': 'executable',
        'netconf_command': 'netconf-command',
        'notification': 'notification',
        'condition': 'condition',
        'condition_description': 'condition-description',
        'condition_type': 'condition-type',
        'dependencies': 'dependencies',
        'description': 'description',
        'input': 'input',
        'output': 'output',
        'step_name': 'step-name',
        'suspend': 'suspend',
        'task': 'task',
        'workflow': 'workflow'
    }

    def __init__(self, cli_command=None, executable=None, netconf_command=None, notification=None, condition=None, condition_description=None, condition_type=None, dependencies=None, description=None, input=None, output=None, step_name=None, suspend=None, task=None, workflow=None):  # noqa: E501
        """WorkflowSchemaStep - a model defined in Swagger"""  # noqa: E501

        self._cli_command = None
        self._executable = None
        self._netconf_command = None
        self._notification = None
        self._condition = None
        self._condition_description = None
        self._condition_type = None
        self._dependencies = None
        self._description = None
        self._input = None
        self._output = None
        self._step_name = None
        self._suspend = None
        self._task = None
        self._workflow = None
        self.discriminator = None

        if cli_command is not None:
            self.cli_command = cli_command
        if executable is not None:
            self.executable = executable
        if netconf_command is not None:
            self.netconf_command = netconf_command
        if notification is not None:
            self.notification = notification
        if condition is not None:
            self.condition = condition
        if condition_description is not None:
            self.condition_description = condition_description
        if condition_type is not None:
            self.condition_type = condition_type
        if dependencies is not None:
            self.dependencies = dependencies
        if description is not None:
            self.description = description
        if input is not None:
            self.input = input
        if output is not None:
            self.output = output
        self.step_name = step_name
        if suspend is not None:
            self.suspend = suspend
        if task is not None:
            self.task = task
        if workflow is not None:
            self.workflow = workflow

    @property
    def cli_command(self):
        """Gets the cli_command of this WorkflowSchemaStep.  # noqa: E501

        Run CLI command(s)  # noqa: E501

        :return: The cli_command of this WorkflowSchemaStep.  # noqa: E501
        :rtype: list[WorkflowCommandSchema]
        """
        return self._cli_command

    @cli_command.setter
    def cli_command(self, cli_command):
        """Sets the cli_command of this WorkflowSchemaStep.

        Run CLI command(s)  # noqa: E501

        :param cli_command: The cli_command of this WorkflowSchemaStep.  # noqa: E501
        :type: list[WorkflowCommandSchema]
        """

        self._cli_command = cli_command

    @property
    def executable(self):
        """Gets the executable of this WorkflowSchemaStep.  # noqa: E501

        Run an arbitrary executable file such as bash, python, ruby, etc.  # noqa: E501

        :return: The executable of this WorkflowSchemaStep.  # noqa: E501
        :rtype: list[WorkflowCommandSchema]
        """
        return self._executable

    @executable.setter
    def executable(self, executable):
        """Sets the executable of this WorkflowSchemaStep.

        Run an arbitrary executable file such as bash, python, ruby, etc.  # noqa: E501

        :param executable: The executable of this WorkflowSchemaStep.  # noqa: E501
        :type: list[WorkflowCommandSchema]
        """

        self._executable = executable

    @property
    def netconf_command(self):
        """Gets the netconf_command of this WorkflowSchemaStep.  # noqa: E501

        Run netconf command(s)  # noqa: E501

        :return: The netconf_command of this WorkflowSchemaStep.  # noqa: E501
        :rtype: list[WorkflowCommandSchema]
        """
        return self._netconf_command

    @netconf_command.setter
    def netconf_command(self, netconf_command):
        """Sets the netconf_command of this WorkflowSchemaStep.

        Run netconf command(s)  # noqa: E501

        :param netconf_command: The netconf_command of this WorkflowSchemaStep.  # noqa: E501
        :type: list[WorkflowCommandSchema]
        """

        self._netconf_command = netconf_command

    @property
    def notification(self):
        """Gets the notification of this WorkflowSchemaStep.  # noqa: E501

        Send a notification message (configured under notification section)  # noqa: E501

        :return: The notification of this WorkflowSchemaStep.  # noqa: E501
        :rtype: list[WorkflowNotificationSchema]
        """
        return self._notification

    @notification.setter
    def notification(self, notification):
        """Sets the notification of this WorkflowSchemaStep.

        Send a notification message (configured under notification section)  # noqa: E501

        :param notification: The notification of this WorkflowSchemaStep.  # noqa: E501
        :type: list[WorkflowNotificationSchema]
        """

        self._notification = notification

    @property
    def condition(self):
        """Gets the condition of this WorkflowSchemaStep.  # noqa: E501


        :return: The condition of this WorkflowSchemaStep.  # noqa: E501
        :rtype: list[str]
        """
        return self._condition

    @condition.setter
    def condition(self, condition):
        """Sets the condition of this WorkflowSchemaStep.


        :param condition: The condition of this WorkflowSchemaStep.  # noqa: E501
        :type: list[str]
        """

        self._condition = condition

    @property
    def condition_description(self):
        """Gets the condition_description of this WorkflowSchemaStep.  # noqa: E501

        Description of the configured conditions  # noqa: E501

        :return: The condition_description of this WorkflowSchemaStep.  # noqa: E501
        :rtype: str
        """
        return self._condition_description

    @condition_description.setter
    def condition_description(self, condition_description):
        """Sets the condition_description of this WorkflowSchemaStep.

        Description of the configured conditions  # noqa: E501

        :param condition_description: The condition_description of this WorkflowSchemaStep.  # noqa: E501
        :type: str
        """

        self._condition_description = condition_description

    @property
    def condition_type(self):
        """Gets the condition_type of this WorkflowSchemaStep.  # noqa: E501

        Call the step if any of the conditions evaluates to true or all of the conditions evaluate to true (default any)  # noqa: E501

        :return: The condition_type of this WorkflowSchemaStep.  # noqa: E501
        :rtype: str
        """
        return self._condition_type

    @condition_type.setter
    def condition_type(self, condition_type):
        """Sets the condition_type of this WorkflowSchemaStep.

        Call the step if any of the conditions evaluates to true or all of the conditions evaluate to true (default any)  # noqa: E501

        :param condition_type: The condition_type of this WorkflowSchemaStep.  # noqa: E501
        :type: str
        """
        allowed_values = ["any", "all"]  # noqa: E501
        if condition_type not in allowed_values:
            raise ValueError(
                "Invalid value for `condition_type` ({0}), must be one of {1}"  # noqa: E501
                .format(condition_type, allowed_values)
            )

        self._condition_type = condition_type

    @property
    def dependencies(self):
        """Gets the dependencies of this WorkflowSchemaStep.  # noqa: E501


        :return: The dependencies of this WorkflowSchemaStep.  # noqa: E501
        :rtype: list[str]
        """
        return self._dependencies

    @dependencies.setter
    def dependencies(self, dependencies):
        """Sets the dependencies of this WorkflowSchemaStep.


        :param dependencies: The dependencies of this WorkflowSchemaStep.  # noqa: E501
        :type: list[str]
        """

        self._dependencies = dependencies

    @property
    def description(self):
        """Gets the description of this WorkflowSchemaStep.  # noqa: E501

        Description about the step being called  # noqa: E501

        :return: The description of this WorkflowSchemaStep.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this WorkflowSchemaStep.

        Description about the step being called  # noqa: E501

        :param description: The description of this WorkflowSchemaStep.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def input(self):
        """Gets the input of this WorkflowSchemaStep.  # noqa: E501

        Workflow input parameters configuration  # noqa: E501

        :return: The input of this WorkflowSchemaStep.  # noqa: E501
        :rtype: list[WorkflowSchemaInput]
        """
        return self._input

    @input.setter
    def input(self, input):
        """Sets the input of this WorkflowSchemaStep.

        Workflow input parameters configuration  # noqa: E501

        :param input: The input of this WorkflowSchemaStep.  # noqa: E501
        :type: list[WorkflowSchemaInput]
        """

        self._input = input

    @property
    def output(self):
        """Gets the output of this WorkflowSchemaStep.  # noqa: E501

        Workflow output parameters configuration  # noqa: E501

        :return: The output of this WorkflowSchemaStep.  # noqa: E501
        :rtype: list[WorkflowSchemaOutput]
        """
        return self._output

    @output.setter
    def output(self, output):
        """Sets the output of this WorkflowSchemaStep.

        Workflow output parameters configuration  # noqa: E501

        :param output: The output of this WorkflowSchemaStep.  # noqa: E501
        :type: list[WorkflowSchemaOutput]
        """

        self._output = output

    @property
    def step_name(self):
        """Gets the step_name of this WorkflowSchemaStep.  # noqa: E501

        Name of the step being called. Should be of pattern [a-zA-Z][a-zA-Z0-9_-]*  # noqa: E501

        :return: The step_name of this WorkflowSchemaStep.  # noqa: E501
        :rtype: str
        """
        return self._step_name

    @step_name.setter
    def step_name(self, step_name):
        """Sets the step_name of this WorkflowSchemaStep.

        Name of the step being called. Should be of pattern [a-zA-Z][a-zA-Z0-9_-]*  # noqa: E501

        :param step_name: The step_name of this WorkflowSchemaStep.  # noqa: E501
        :type: str
        """
        if step_name is None:
            raise ValueError("Invalid value for `step_name`, must not be `None`")  # noqa: E501
        if step_name is not None and len(step_name) > 64:
            raise ValueError("Invalid value for `step_name`, length must be less than or equal to `64`")  # noqa: E501
        if step_name is not None and len(step_name) < 1:
            raise ValueError("Invalid value for `step_name`, length must be greater than or equal to `1`")  # noqa: E501
        if step_name is not None and not re.search(r'^[a-zA-Z][a-zA-Z0-9_-]*$', step_name):  # noqa: E501
            raise ValueError(r"Invalid value for `step_name`, must be a follow pattern or equal to `/^[a-zA-Z][a-zA-Z0-9_-]*$/`")  # noqa: E501

        self._step_name = step_name

    @property
    def suspend(self):
        """Gets the suspend of this WorkflowSchemaStep.  # noqa: E501


        :return: The suspend of this WorkflowSchemaStep.  # noqa: E501
        :rtype: WorkflowSchemaSuspend
        """
        return self._suspend

    @suspend.setter
    def suspend(self, suspend):
        """Sets the suspend of this WorkflowSchemaStep.


        :param suspend: The suspend of this WorkflowSchemaStep.  # noqa: E501
        :type: WorkflowSchemaSuspend
        """

        self._suspend = suspend

    @property
    def task(self):
        """Gets the task of this WorkflowSchemaStep.  # noqa: E501


        :return: The task of this WorkflowSchemaStep.  # noqa: E501
        :rtype: WorkflowSchemaTask
        """
        return self._task

    @task.setter
    def task(self, task):
        """Sets the task of this WorkflowSchemaStep.


        :param task: The task of this WorkflowSchemaStep.  # noqa: E501
        :type: WorkflowSchemaTask
        """

        self._task = task

    @property
    def workflow(self):
        """Gets the workflow of this WorkflowSchemaStep.  # noqa: E501


        :return: The workflow of this WorkflowSchemaStep.  # noqa: E501
        :rtype: WorkflowSchemaWorkflow
        """
        return self._workflow

    @workflow.setter
    def workflow(self, workflow):
        """Sets the workflow of this WorkflowSchemaStep.


        :param workflow: The workflow of this WorkflowSchemaStep.  # noqa: E501
        :type: WorkflowSchemaWorkflow
        """

        self._workflow = workflow

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WorkflowSchemaStep, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WorkflowSchemaStep):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class SchedulerSchema(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'end_time': 'str',
        'name': 'str',
        'repeat': 'SchedulerSchemaRepeat',
        'start_time': 'str',
        'run_for': 'SchedulerSchemaRunfor',
        'type': 'str'
    }

    attribute_map = {
        'end_time': 'end-time',
        'name': 'name',
        'repeat': 'repeat',
        'start_time': 'start-time',
        'run_for': 'run-for',
        'type': 'type'
    }

    def __init__(self, end_time=None, name=None, repeat=None, start_time=None, run_for=None, type='continuous'):  # noqa: E501
        """SchedulerSchema - a model defined in Swagger"""  # noqa: E501

        self._end_time = None
        self._name = None
        self._repeat = None
        self._start_time = None
        self._run_for = None
        self._type = None
        self.discriminator = None

        if end_time is not None:
            self.end_time = end_time
        self.name = name
        self.repeat = repeat
        self.start_time = start_time
        if run_for is not None:
            self.run_for = run_for
        if type is not None:
            self.type = type

    @property
    def end_time(self):
        """Gets the end_time of this SchedulerSchema.  # noqa: E501

        End scheduler at this time  # noqa: E501

        :return: The end_time of this SchedulerSchema.  # noqa: E501
        :rtype: str
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this SchedulerSchema.

        End scheduler at this time  # noqa: E501

        :param end_time: The end_time of this SchedulerSchema.  # noqa: E501
        :type: str
        """
        if end_time is not None and not re.search(r'^[0-9]{4}-(0[1-9]|1[0-2])-(0[1-9]|[1-2][0-9]|3[01])T([0-1][0-9]|2[0-3]):[0-5][0-9]:[0-5][0-9]Z$', end_time):  # noqa: E501
            raise ValueError(r"Invalid value for `end_time`, must be a follow pattern or equal to `/^[0-9]{4}-(0[1-9]|1[0-2])-(0[1-9]|[1-2][0-9]|3[01])T([0-1][0-9]|2[0-3]):[0-5][0-9]:[0-5][0-9]Z$/`")  # noqa: E501

        self._end_time = end_time

    @property
    def name(self):
        """Gets the name of this SchedulerSchema.  # noqa: E501

        Name of the scheduler  # noqa: E501

        :return: The name of this SchedulerSchema.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SchedulerSchema.

        Name of the scheduler  # noqa: E501

        :param name: The name of this SchedulerSchema.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if name is not None and not re.search(r'^[a-zA-Z][a-zA-Z0-9_-]*$', name):  # noqa: E501
            raise ValueError(r"Invalid value for `name`, must be a follow pattern or equal to `/^[a-zA-Z][a-zA-Z0-9_-]*$/`")  # noqa: E501

        self._name = name

    @property
    def repeat(self):
        """Gets the repeat of this SchedulerSchema.  # noqa: E501


        :return: The repeat of this SchedulerSchema.  # noqa: E501
        :rtype: SchedulerSchemaRepeat
        """
        return self._repeat

    @repeat.setter
    def repeat(self, repeat):
        """Sets the repeat of this SchedulerSchema.


        :param repeat: The repeat of this SchedulerSchema.  # noqa: E501
        :type: SchedulerSchemaRepeat
        """
        if repeat is None:
            raise ValueError("Invalid value for `repeat`, must not be `None`")  # noqa: E501

        self._repeat = repeat

    @property
    def start_time(self):
        """Gets the start_time of this SchedulerSchema.  # noqa: E501

        Start scheduler at this time  # noqa: E501

        :return: The start_time of this SchedulerSchema.  # noqa: E501
        :rtype: str
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this SchedulerSchema.

        Start scheduler at this time  # noqa: E501

        :param start_time: The start_time of this SchedulerSchema.  # noqa: E501
        :type: str
        """
        if start_time is None:
            raise ValueError("Invalid value for `start_time`, must not be `None`")  # noqa: E501
        if start_time is not None and not re.search(r'^[0-9]{4}-(0[1-9]|1[0-2])-(0[1-9]|[1-2][0-9]|3[01])T([0-1][0-9]|2[0-3]):[0-5][0-9]:[0-5][0-9]Z$', start_time):  # noqa: E501
            raise ValueError(r"Invalid value for `start_time`, must be a follow pattern or equal to `/^[0-9]{4}-(0[1-9]|1[0-2])-(0[1-9]|[1-2][0-9]|3[01])T([0-1][0-9]|2[0-3]):[0-5][0-9]:[0-5][0-9]Z$/`")  # noqa: E501

        self._start_time = start_time

    @property
    def run_for(self):
        """Gets the run_for of this SchedulerSchema.  # noqa: E501


        :return: The run_for of this SchedulerSchema.  # noqa: E501
        :rtype: SchedulerSchemaRunfor
        """
        return self._run_for

    @run_for.setter
    def run_for(self, run_for):
        """Sets the run_for of this SchedulerSchema.


        :param run_for: The run_for of this SchedulerSchema.  # noqa: E501
        :type: SchedulerSchemaRunfor
        """

        self._run_for = run_for

    @property
    def type(self):
        """Gets the type of this SchedulerSchema.  # noqa: E501

        Type of the scheduler.  # noqa: E501

        :return: The type of this SchedulerSchema.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this SchedulerSchema.

        Type of the scheduler.  # noqa: E501

        :param type: The type of this SchedulerSchema.  # noqa: E501
        :type: str
        """
        allowed_values = ["continuous", "discrete"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SchedulerSchema, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SchedulerSchema):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class TopicSchemaWithcapturegroup(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'capture_group_name': 'str',
        'expression': 'str',
        'field_name': 'str',
        'ignore_case': 'bool'
    }

    attribute_map = {
        'capture_group_name': 'capture-group-name',
        'expression': 'expression',
        'field_name': 'field-name',
        'ignore_case': 'ignore-case'
    }

    def __init__(self, capture_group_name=None, expression=None, field_name=None, ignore_case=None):  # noqa: E501
        """TopicSchemaWithcapturegroup - a model defined in Swagger"""  # noqa: E501

        self._capture_group_name = None
        self._expression = None
        self._field_name = None
        self._ignore_case = None
        self.discriminator = None

        self.capture_group_name = capture_group_name
        if expression is not None:
            self.expression = expression
        if field_name is not None:
            self.field_name = field_name
        if ignore_case is not None:
            self.ignore_case = ignore_case

    @property
    def capture_group_name(self):
        """Gets the capture_group_name of this TopicSchemaWithcapturegroup.  # noqa: E501

        Name of the capture group. Should be of pattern [a-zA-Z][a-zA-Z0-9-]*  # noqa: E501

        :return: The capture_group_name of this TopicSchemaWithcapturegroup.  # noqa: E501
        :rtype: str
        """
        return self._capture_group_name

    @capture_group_name.setter
    def capture_group_name(self, capture_group_name):
        """Sets the capture_group_name of this TopicSchemaWithcapturegroup.

        Name of the capture group. Should be of pattern [a-zA-Z][a-zA-Z0-9-]*  # noqa: E501

        :param capture_group_name: The capture_group_name of this TopicSchemaWithcapturegroup.  # noqa: E501
        :type: str
        """
        if capture_group_name is None:
            raise ValueError("Invalid value for `capture_group_name`, must not be `None`")  # noqa: E501
        if capture_group_name is not None and len(capture_group_name) > 64:
            raise ValueError("Invalid value for `capture_group_name`, length must be less than or equal to `64`")  # noqa: E501
        if capture_group_name is not None and len(capture_group_name) < 1:
            raise ValueError("Invalid value for `capture_group_name`, length must be greater than or equal to `1`")  # noqa: E501
        if capture_group_name is not None and not re.search(r'^[a-zA-Z][a-zA-Z0-9-]*$', capture_group_name):  # noqa: E501
            raise ValueError(r"Invalid value for `capture_group_name`, must be a follow pattern or equal to `/^[a-zA-Z][a-zA-Z0-9-]*$/`")  # noqa: E501

        self._capture_group_name = capture_group_name

    @property
    def expression(self):
        """Gets the expression of this TopicSchemaWithcapturegroup.  # noqa: E501

        Regular expression to extract sub strings  # noqa: E501

        :return: The expression of this TopicSchemaWithcapturegroup.  # noqa: E501
        :rtype: str
        """
        return self._expression

    @expression.setter
    def expression(self, expression):
        """Sets the expression of this TopicSchemaWithcapturegroup.

        Regular expression to extract sub strings  # noqa: E501

        :param expression: The expression of this TopicSchemaWithcapturegroup.  # noqa: E501
        :type: str
        """

        self._expression = expression

    @property
    def field_name(self):
        """Gets the field_name of this TopicSchemaWithcapturegroup.  # noqa: E501

        Name of the local or depending resource field name  # noqa: E501

        :return: The field_name of this TopicSchemaWithcapturegroup.  # noqa: E501
        :rtype: str
        """
        return self._field_name

    @field_name.setter
    def field_name(self, field_name):
        """Sets the field_name of this TopicSchemaWithcapturegroup.

        Name of the local or depending resource field name  # noqa: E501

        :param field_name: The field_name of this TopicSchemaWithcapturegroup.  # noqa: E501
        :type: str
        """

        self._field_name = field_name

    @property
    def ignore_case(self):
        """Gets the ignore_case of this TopicSchemaWithcapturegroup.  # noqa: E501

        If true, regex match with be case insensitive  # noqa: E501

        :return: The ignore_case of this TopicSchemaWithcapturegroup.  # noqa: E501
        :rtype: bool
        """
        return self._ignore_case

    @ignore_case.setter
    def ignore_case(self, ignore_case):
        """Sets the ignore_case of this TopicSchemaWithcapturegroup.

        If true, regex match with be case insensitive  # noqa: E501

        :param ignore_case: The ignore_case of this TopicSchemaWithcapturegroup.  # noqa: E501
        :type: bool
        """

        self._ignore_case = ignore_case

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TopicSchemaWithcapturegroup, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TopicSchemaWithcapturegroup):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class WorkflowSchemaOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'artifact': 'WorkflowSchemaArtifact',
        'command_tag': 'str',
        'data_xml': 'WorkflowSchemaDataxml',
        'description': 'str',
        'grok': 'WorkflowSchemaGrok',
        'json': 'WorkflowSchemaJson',
        'name': 'str',
        'result': 'list[object]',
        'regex': 'WorkflowSchemaRegex'
    }

    attribute_map = {
        'artifact': 'artifact',
        'command_tag': 'command-tag',
        'data_xml': 'data-xml',
        'description': 'description',
        'grok': 'grok',
        'json': 'json',
        'name': 'name',
        'result': 'result',
        'regex': 'regex'
    }

    def __init__(self, artifact=None, command_tag=None, data_xml=None, description=None, grok=None, json=None, name=None, result=None, regex=None):  # noqa: E501
        """WorkflowSchemaOutput - a model defined in Swagger"""  # noqa: E501

        self._artifact = None
        self._command_tag = None
        self._data_xml = None
        self._description = None
        self._grok = None
        self._json = None
        self._name = None
        self._result = None
        self._regex = None
        self.discriminator = None

        if artifact is not None:
            self.artifact = artifact
        if command_tag is not None:
            self.command_tag = command_tag
        if data_xml is not None:
            self.data_xml = data_xml
        if description is not None:
            self.description = description
        if grok is not None:
            self.grok = grok
        if json is not None:
            self.json = json
        self.name = name
        if result is not None:
            self.result = result
        if regex is not None:
            self.regex = regex

    @property
    def artifact(self):
        """Gets the artifact of this WorkflowSchemaOutput.  # noqa: E501


        :return: The artifact of this WorkflowSchemaOutput.  # noqa: E501
        :rtype: WorkflowSchemaArtifact
        """
        return self._artifact

    @artifact.setter
    def artifact(self, artifact):
        """Sets the artifact of this WorkflowSchemaOutput.


        :param artifact: The artifact of this WorkflowSchemaOutput.  # noqa: E501
        :type: WorkflowSchemaArtifact
        """

        self._artifact = artifact

    @property
    def command_tag(self):
        """Gets the command_tag of this WorkflowSchemaOutput.  # noqa: E501

        Command tag whose output is used for pattern match  # noqa: E501

        :return: The command_tag of this WorkflowSchemaOutput.  # noqa: E501
        :rtype: str
        """
        return self._command_tag

    @command_tag.setter
    def command_tag(self, command_tag):
        """Sets the command_tag of this WorkflowSchemaOutput.

        Command tag whose output is used for pattern match  # noqa: E501

        :param command_tag: The command_tag of this WorkflowSchemaOutput.  # noqa: E501
        :type: str
        """

        self._command_tag = command_tag

    @property
    def data_xml(self):
        """Gets the data_xml of this WorkflowSchemaOutput.  # noqa: E501


        :return: The data_xml of this WorkflowSchemaOutput.  # noqa: E501
        :rtype: WorkflowSchemaDataxml
        """
        return self._data_xml

    @data_xml.setter
    def data_xml(self, data_xml):
        """Sets the data_xml of this WorkflowSchemaOutput.


        :param data_xml: The data_xml of this WorkflowSchemaOutput.  # noqa: E501
        :type: WorkflowSchemaDataxml
        """

        self._data_xml = data_xml

    @property
    def description(self):
        """Gets the description of this WorkflowSchemaOutput.  # noqa: E501

        Exported output field desciption  # noqa: E501

        :return: The description of this WorkflowSchemaOutput.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this WorkflowSchemaOutput.

        Exported output field desciption  # noqa: E501

        :param description: The description of this WorkflowSchemaOutput.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def grok(self):
        """Gets the grok of this WorkflowSchemaOutput.  # noqa: E501


        :return: The grok of this WorkflowSchemaOutput.  # noqa: E501
        :rtype: WorkflowSchemaGrok
        """
        return self._grok

    @grok.setter
    def grok(self, grok):
        """Sets the grok of this WorkflowSchemaOutput.


        :param grok: The grok of this WorkflowSchemaOutput.  # noqa: E501
        :type: WorkflowSchemaGrok
        """

        self._grok = grok

    @property
    def json(self):
        """Gets the json of this WorkflowSchemaOutput.  # noqa: E501


        :return: The json of this WorkflowSchemaOutput.  # noqa: E501
        :rtype: WorkflowSchemaJson
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this WorkflowSchemaOutput.


        :param json: The json of this WorkflowSchemaOutput.  # noqa: E501
        :type: WorkflowSchemaJson
        """

        self._json = json

    @property
    def name(self):
        """Gets the name of this WorkflowSchemaOutput.  # noqa: E501

        Output parameter name exported from the workflow. Should be of pattern [a-zA-Z][a-zA-Z0-9_-]*  # noqa: E501

        :return: The name of this WorkflowSchemaOutput.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this WorkflowSchemaOutput.

        Output parameter name exported from the workflow. Should be of pattern [a-zA-Z][a-zA-Z0-9_-]*  # noqa: E501

        :param name: The name of this WorkflowSchemaOutput.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if name is not None and len(name) > 64:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `64`")  # noqa: E501
        if name is not None and len(name) < 1:
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501
        if name is not None and not re.search(r'^[a-zA-Z][a-zA-Z0-9_-]*$', name):  # noqa: E501
            raise ValueError(r"Invalid value for `name`, must be a follow pattern or equal to `/^[a-zA-Z][a-zA-Z0-9_-]*$/`")  # noqa: E501

        self._name = name

    @property
    def result(self):
        """Gets the result of this WorkflowSchemaOutput.  # noqa: E501

        Export stdout output (stdout) of the step  # noqa: E501

        :return: The result of this WorkflowSchemaOutput.  # noqa: E501
        :rtype: list[object]
        """
        return self._result

    @result.setter
    def result(self, result):
        """Sets the result of this WorkflowSchemaOutput.

        Export stdout output (stdout) of the step  # noqa: E501

        :param result: The result of this WorkflowSchemaOutput.  # noqa: E501
        :type: list[object]
        """

        self._result = result

    @property
    def regex(self):
        """Gets the regex of this WorkflowSchemaOutput.  # noqa: E501


        :return: The regex of this WorkflowSchemaOutput.  # noqa: E501
        :rtype: WorkflowSchemaRegex
        """
        return self._regex

    @regex.setter
    def regex(self, regex):
        """Sets the regex of this WorkflowSchemaOutput.


        :param regex: The regex of this WorkflowSchemaOutput.  # noqa: E501
        :type: WorkflowSchemaRegex
        """

        self._regex = regex

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WorkflowSchemaOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WorkflowSchemaOutput):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class NetworkgroupSchemaNotification(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'enable': 'list[object]',
        'major': 'list[str]',
        'minor': 'list[str]',
        'normal': 'list[str]'
    }

    attribute_map = {
        'enable': 'enable',
        'major': 'major',
        'minor': 'minor',
        'normal': 'normal'
    }

    def __init__(self, enable=None, major=None, minor=None, normal=None):  # noqa: E501
        """NetworkgroupSchemaNotification - a model defined in Swagger"""  # noqa: E501

        self._enable = None
        self._major = None
        self._minor = None
        self._normal = None
        self.discriminator = None

        if enable is not None:
            self.enable = enable
        if major is not None:
            self.major = major
        if minor is not None:
            self.minor = minor
        if normal is not None:
            self.normal = normal

    @property
    def enable(self):
        """Gets the enable of this NetworkgroupSchemaNotification.  # noqa: E501

        Turn on notifications  # noqa: E501

        :return: The enable of this NetworkgroupSchemaNotification.  # noqa: E501
        :rtype: list[object]
        """
        return self._enable

    @enable.setter
    def enable(self, enable):
        """Sets the enable of this NetworkgroupSchemaNotification.

        Turn on notifications  # noqa: E501

        :param enable: The enable of this NetworkgroupSchemaNotification.  # noqa: E501
        :type: list[object]
        """

        self._enable = enable

    @property
    def major(self):
        """Gets the major of this NetworkgroupSchemaNotification.  # noqa: E501


        :return: The major of this NetworkgroupSchemaNotification.  # noqa: E501
        :rtype: list[str]
        """
        return self._major

    @major.setter
    def major(self, major):
        """Sets the major of this NetworkgroupSchemaNotification.


        :param major: The major of this NetworkgroupSchemaNotification.  # noqa: E501
        :type: list[str]
        """

        self._major = major

    @property
    def minor(self):
        """Gets the minor of this NetworkgroupSchemaNotification.  # noqa: E501


        :return: The minor of this NetworkgroupSchemaNotification.  # noqa: E501
        :rtype: list[str]
        """
        return self._minor

    @minor.setter
    def minor(self, minor):
        """Sets the minor of this NetworkgroupSchemaNotification.


        :param minor: The minor of this NetworkgroupSchemaNotification.  # noqa: E501
        :type: list[str]
        """

        self._minor = minor

    @property
    def normal(self):
        """Gets the normal of this NetworkgroupSchemaNotification.  # noqa: E501


        :return: The normal of this NetworkgroupSchemaNotification.  # noqa: E501
        :rtype: list[str]
        """
        return self._normal

    @normal.setter
    def normal(self, normal):
        """Sets the normal of this NetworkgroupSchemaNotification.


        :param normal: The normal of this NetworkgroupSchemaNotification.  # noqa: E501
        :type: list[str]
        """

        self._normal = normal

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NetworkgroupSchemaNotification, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NetworkgroupSchemaNotification):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class WorkflowSchemaInput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'value': 'str',
        'artifact': 'list[object]'
    }

    attribute_map = {
        'name': 'name',
        'value': 'value',
        'artifact': 'artifact'
    }

    def __init__(self, name=None, value=None, artifact=None):  # noqa: E501
        """WorkflowSchemaInput - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._value = None
        self._artifact = None
        self.discriminator = None

        self.name = name
        if value is not None:
            self.value = value
        if artifact is not None:
            self.artifact = artifact

    @property
    def name(self):
        """Gets the name of this WorkflowSchemaInput.  # noqa: E501

        Input paraameter name passed. Should be of pattern [a-zA-Z][a-zA-Z0-9_-]*  # noqa: E501

        :return: The name of this WorkflowSchemaInput.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this WorkflowSchemaInput.

        Input paraameter name passed. Should be of pattern [a-zA-Z][a-zA-Z0-9_-]*  # noqa: E501

        :param name: The name of this WorkflowSchemaInput.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if name is not None and len(name) > 64:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `64`")  # noqa: E501
        if name is not None and len(name) < 1:
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501
        if name is not None and not re.search(r'^[a-zA-Z][a-zA-Z0-9_-]*$', name):  # noqa: E501
            raise ValueError(r"Invalid value for `name`, must be a follow pattern or equal to `/^[a-zA-Z][a-zA-Z0-9_-]*$/`")  # noqa: E501

        self._name = name

    @property
    def value(self):
        """Gets the value of this WorkflowSchemaInput.  # noqa: E501

        Input parameter value passed  # noqa: E501

        :return: The value of this WorkflowSchemaInput.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this WorkflowSchemaInput.

        Input parameter value passed  # noqa: E501

        :param value: The value of this WorkflowSchemaInput.  # noqa: E501
        :type: str
        """

        self._value = value

    @property
    def artifact(self):
        """Gets the artifact of this WorkflowSchemaInput.  # noqa: E501

        Input data are artifact  # noqa: E501

        :return: The artifact of this WorkflowSchemaInput.  # noqa: E501
        :rtype: list[object]
        """
        return self._artifact

    @artifact.setter
    def artifact(self, artifact):
        """Sets the artifact of this WorkflowSchemaInput.

        Input data are artifact  # noqa: E501

        :param artifact: The artifact of this WorkflowSchemaInput.  # noqa: E501
        :type: list[object]
        """

        self._artifact = artifact

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WorkflowSchemaInput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WorkflowSchemaInput):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class DeviceSchemaVariable(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'instance_id': 'str',
        'playbook': 'str',
        'rule': 'str',
        'variable_value': 'list[DevicegroupSchemaVariablevalue]'
    }

    attribute_map = {
        'instance_id': 'instance-id',
        'playbook': 'playbook',
        'rule': 'rule',
        'variable_value': 'variable-value'
    }

    def __init__(self, instance_id=None, playbook=None, rule=None, variable_value=None):  # noqa: E501
        """DeviceSchemaVariable - a model defined in Swagger"""  # noqa: E501

        self._instance_id = None
        self._playbook = None
        self._rule = None
        self._variable_value = None
        self.discriminator = None

        self.instance_id = instance_id
        self.playbook = playbook
        self.rule = rule
        if variable_value is not None:
            self.variable_value = variable_value

    @property
    def instance_id(self):
        """Gets the instance_id of this DeviceSchemaVariable.  # noqa: E501

        Name of the variable instance. Should be of pattern [a-zA-Z][a-zA-Z0-9_-]*  # noqa: E501

        :return: The instance_id of this DeviceSchemaVariable.  # noqa: E501
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """Sets the instance_id of this DeviceSchemaVariable.

        Name of the variable instance. Should be of pattern [a-zA-Z][a-zA-Z0-9_-]*  # noqa: E501

        :param instance_id: The instance_id of this DeviceSchemaVariable.  # noqa: E501
        :type: str
        """
        if instance_id is None:
            raise ValueError("Invalid value for `instance_id`, must not be `None`")  # noqa: E501
        if instance_id is not None and len(instance_id) > 64:
            raise ValueError("Invalid value for `instance_id`, length must be less than or equal to `64`")  # noqa: E501
        if instance_id is not None and not re.search(r'^[a-zA-Z][a-zA-Z0-9_-]*$', instance_id):  # noqa: E501
            raise ValueError(r"Invalid value for `instance_id`, must be a follow pattern or equal to `/^[a-zA-Z][a-zA-Z0-9_-]*$/`")  # noqa: E501

        self._instance_id = instance_id

    @property
    def playbook(self):
        """Gets the playbook of this DeviceSchemaVariable.  # noqa: E501

        Name of the playbook in which the variable instance needs to be used  # noqa: E501

        :return: The playbook of this DeviceSchemaVariable.  # noqa: E501
        :rtype: str
        """
        return self._playbook

    @playbook.setter
    def playbook(self, playbook):
        """Sets the playbook of this DeviceSchemaVariable.

        Name of the playbook in which the variable instance needs to be used  # noqa: E501

        :param playbook: The playbook of this DeviceSchemaVariable.  # noqa: E501
        :type: str
        """
        if playbook is None:
            raise ValueError("Invalid value for `playbook`, must not be `None`")  # noqa: E501
        if playbook is not None and len(playbook) > 64:
            raise ValueError("Invalid value for `playbook`, length must be less than or equal to `64`")  # noqa: E501
        if playbook is not None and not re.search(r'^[a-zA-Z][a-zA-Z0-9_-]*$', playbook):  # noqa: E501
            raise ValueError(r"Invalid value for `playbook`, must be a follow pattern or equal to `/^[a-zA-Z][a-zA-Z0-9_-]*$/`")  # noqa: E501

        self._playbook = playbook

    @property
    def rule(self):
        """Gets the rule of this DeviceSchemaVariable.  # noqa: E501

        Name of the rule. This must be of the format <topic-name>/<rule-name>  # noqa: E501

        :return: The rule of this DeviceSchemaVariable.  # noqa: E501
        :rtype: str
        """
        return self._rule

    @rule.setter
    def rule(self, rule):
        """Sets the rule of this DeviceSchemaVariable.

        Name of the rule. This must be of the format <topic-name>/<rule-name>  # noqa: E501

        :param rule: The rule of this DeviceSchemaVariable.  # noqa: E501
        :type: str
        """
        if rule is None:
            raise ValueError("Invalid value for `rule`, must not be `None`")  # noqa: E501
        if rule is not None and not re.search(r'^[a-z][a-z-]*(\\.{1}[a-z0-9-]+)*\/[a-z]+[a-z0-9_-]*$', rule):  # noqa: E501
            raise ValueError(r"Invalid value for `rule`, must be a follow pattern or equal to `/^[a-z][a-z-]*(\\.{1}[a-z0-9-]+)*\/[a-z]+[a-z0-9_-]*$/`")  # noqa: E501

        self._rule = rule

    @property
    def variable_value(self):
        """Gets the variable_value of this DeviceSchemaVariable.  # noqa: E501


        :return: The variable_value of this DeviceSchemaVariable.  # noqa: E501
        :rtype: list[DevicegroupSchemaVariablevalue]
        """
        return self._variable_value

    @variable_value.setter
    def variable_value(self, variable_value):
        """Sets the variable_value of this DeviceSchemaVariable.


        :param variable_value: The variable_value of this DeviceSchemaVariable.  # noqa: E501
        :type: list[DevicegroupSchemaVariablevalue]
        """

        self._variable_value = variable_value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DeviceSchemaVariable, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeviceSchemaVariable):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Event(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'color': 'str',
        'event_name': 'str',
        'frequency': 'int',
        'timestamp': 'datetime'
    }

    attribute_map = {
        'color': 'color',
        'event_name': 'event_name',
        'frequency': 'frequency',
        'timestamp': 'timestamp'
    }

    def __init__(self, color=None, event_name=None, frequency=None, timestamp=None):  # noqa: E501
        """Event - a model defined in Swagger"""  # noqa: E501

        self._color = None
        self._event_name = None
        self._frequency = None
        self._timestamp = None
        self.discriminator = None

        if color is not None:
            self.color = color
        if event_name is not None:
            self.event_name = event_name
        if frequency is not None:
            self.frequency = frequency
        if timestamp is not None:
            self.timestamp = timestamp

    @property
    def color(self):
        """Gets the color of this Event.  # noqa: E501

        Event severity  # noqa: E501

        :return: The color of this Event.  # noqa: E501
        :rtype: str
        """
        return self._color

    @color.setter
    def color(self, color):
        """Sets the color of this Event.

        Event severity  # noqa: E501

        :param color: The color of this Event.  # noqa: E501
        :type: str
        """
        allowed_values = ["yellow", "red"]  # noqa: E501
        if color not in allowed_values:
            raise ValueError(
                "Invalid value for `color` ({0}), must be one of {1}"  # noqa: E501
                .format(color, allowed_values)
            )

        self._color = color

    @property
    def event_name(self):
        """Gets the event_name of this Event.  # noqa: E501

        Event name  # noqa: E501

        :return: The event_name of this Event.  # noqa: E501
        :rtype: str
        """
        return self._event_name

    @event_name.setter
    def event_name(self, event_name):
        """Sets the event_name of this Event.

        Event name  # noqa: E501

        :param event_name: The event_name of this Event.  # noqa: E501
        :type: str
        """

        self._event_name = event_name

    @property
    def frequency(self):
        """Gets the frequency of this Event.  # noqa: E501

        Frequency of the event.  # noqa: E501

        :return: The frequency of this Event.  # noqa: E501
        :rtype: int
        """
        return self._frequency

    @frequency.setter
    def frequency(self, frequency):
        """Sets the frequency of this Event.

        Frequency of the event.  # noqa: E501

        :param frequency: The frequency of this Event.  # noqa: E501
        :type: int
        """

        self._frequency = frequency

    @property
    def timestamp(self):
        """Gets the timestamp of this Event.  # noqa: E501


        :return: The timestamp of this Event.  # noqa: E501
        :rtype: datetime
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this Event.


        :param timestamp: The timestamp of this Event.  # noqa: E501
        :type: datetime
        """

        self._timestamp = timestamp

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Event, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Event):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RuleSchemaFormulaPredict(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'algorithm': 'str',
        'field_name': 'str',
        'learning_period': 'str',
        'pattern_periodicity': 'str',
        'seasonality': 'str',
        'prediction_offset': 'str'
    }

    attribute_map = {
        'algorithm': 'algorithm',
        'field_name': 'field-name',
        'learning_period': 'learning-period',
        'pattern_periodicity': 'pattern-periodicity',
        'seasonality': 'seasonality',
        'prediction_offset': 'prediction-offset'
    }

    def __init__(self, algorithm=None, field_name=None, learning_period=None, pattern_periodicity=None, seasonality=None, prediction_offset=None):  # noqa: E501
        """RuleSchemaFormulaPredict - a model defined in Swagger"""  # noqa: E501

        self._algorithm = None
        self._field_name = None
        self._learning_period = None
        self._pattern_periodicity = None
        self._seasonality = None
        self._prediction_offset = None
        self.discriminator = None

        self.algorithm = algorithm
        self.field_name = field_name
        self.learning_period = learning_period
        if pattern_periodicity is not None:
            self.pattern_periodicity = pattern_periodicity
        if seasonality is not None:
            self.seasonality = seasonality
        self.prediction_offset = prediction_offset

    @property
    def algorithm(self):
        """Gets the algorithm of this RuleSchemaFormulaPredict.  # noqa: E501

        Algorithm used to create baseline thresholds  # noqa: E501

        :return: The algorithm of this RuleSchemaFormulaPredict.  # noqa: E501
        :rtype: str
        """
        return self._algorithm

    @algorithm.setter
    def algorithm(self, algorithm):
        """Sets the algorithm of this RuleSchemaFormulaPredict.

        Algorithm used to create baseline thresholds  # noqa: E501

        :param algorithm: The algorithm of this RuleSchemaFormulaPredict.  # noqa: E501
        :type: str
        """
        if algorithm is None:
            raise ValueError("Invalid value for `algorithm`, must not be `None`")  # noqa: E501
        allowed_values = ["median-prediction", "holt-winters", "hidden-markov"]  # noqa: E501
        if algorithm not in allowed_values:
            raise ValueError(
                "Invalid value for `algorithm` ({0}), must be one of {1}"  # noqa: E501
                .format(algorithm, allowed_values)
            )

        self._algorithm = algorithm

    @property
    def field_name(self):
        """Gets the field_name of this RuleSchemaFormulaPredict.  # noqa: E501

        Field name on which ML algorithm needs to be applied  # noqa: E501

        :return: The field_name of this RuleSchemaFormulaPredict.  # noqa: E501
        :rtype: str
        """
        return self._field_name

    @field_name.setter
    def field_name(self, field_name):
        """Sets the field_name of this RuleSchemaFormulaPredict.

        Field name on which ML algorithm needs to be applied  # noqa: E501

        :param field_name: The field_name of this RuleSchemaFormulaPredict.  # noqa: E501
        :type: str
        """
        if field_name is None:
            raise ValueError("Invalid value for `field_name`, must not be `None`")  # noqa: E501

        self._field_name = field_name

    @property
    def learning_period(self):
        """Gets the learning_period of this RuleSchemaFormulaPredict.  # noqa: E501

        Learning period to learn the baseline threshold. Should be of pattern [1-9][0-9]*(\\.[0-9]+)?(offset|seconds|minutes|hours|days|weeks|years|o|s|m|h|d|w|y)  # noqa: E501

        :return: The learning_period of this RuleSchemaFormulaPredict.  # noqa: E501
        :rtype: str
        """
        return self._learning_period

    @learning_period.setter
    def learning_period(self, learning_period):
        """Sets the learning_period of this RuleSchemaFormulaPredict.

        Learning period to learn the baseline threshold. Should be of pattern [1-9][0-9]*(\\.[0-9]+)?(offset|seconds|minutes|hours|days|weeks|years|o|s|m|h|d|w|y)  # noqa: E501

        :param learning_period: The learning_period of this RuleSchemaFormulaPredict.  # noqa: E501
        :type: str
        """
        if learning_period is None:
            raise ValueError("Invalid value for `learning_period`, must not be `None`")  # noqa: E501
        if learning_period is not None and not re.search(r'^[1-9][0-9]*(\\.[0-9]+)?(offset|seconds|minutes|hours|days|weeks|years|o|s|m|h|d|w|y)$', learning_period):  # noqa: E501
            raise ValueError(r"Invalid value for `learning_period`, must be a follow pattern or equal to `/^[1-9][0-9]*(\\.[0-9]+)?(offset|seconds|minutes|hours|days|weeks|years|o|s|m|h|d|w|y)$/`")  # noqa: E501

        self._learning_period = learning_period

    @property
    def pattern_periodicity(self):
        """Gets the pattern_periodicity of this RuleSchemaFormulaPredict.  # noqa: E501

        Pattern periodicity. Should be of pattern [1-9][0-9]*(minutes|hours|days|weeks|months)(,[1-9][0-9]*(minutes|hours|days|weeks|months))*  # noqa: E501

        :return: The pattern_periodicity of this RuleSchemaFormulaPredict.  # noqa: E501
        :rtype: str
        """
        return self._pattern_periodicity

    @pattern_periodicity.setter
    def pattern_periodicity(self, pattern_periodicity):
        """Sets the pattern_periodicity of this RuleSchemaFormulaPredict.

        Pattern periodicity. Should be of pattern [1-9][0-9]*(minutes|hours|days|weeks|months)(,[1-9][0-9]*(minutes|hours|days|weeks|months))*  # noqa: E501

        :param pattern_periodicity: The pattern_periodicity of this RuleSchemaFormulaPredict.  # noqa: E501
        :type: str
        """
        if pattern_periodicity is not None and not re.search(r'^[1-9][0-9]*(minutes|hours|days|weeks|months|t|h|d|w|m|T|H|D|W|M)(,[1-9][0-9]*(minutes|hours|days|weeks|months|t|h|d|w|m|T|H|D|W|M))*$', pattern_periodicity):  # noqa: E501
            raise ValueError(r"Invalid value for `pattern_periodicity`, must be a follow pattern or equal to `/^[1-9][0-9]*(minutes|hours|days|weeks|months|t|h|d|w|m|T|H|D|W|M)(,[1-9][0-9]*(minutes|hours|days|weeks|months|t|h|d|w|m|T|H|D|W|M))*$/`")  # noqa: E501

        self._pattern_periodicity = pattern_periodicity

    @property
    def seasonality(self):
        """Gets the seasonality of this RuleSchemaFormulaPredict.  # noqa: E501

        Seasonality. Should be of pattern [1-9][0-9]*(minutes|hours|days|weeks|months)(,[1-9][0-9]*(minutes|hours|days|weeks|months))*  # noqa: E501

        :return: The seasonality of this RuleSchemaFormulaPredict.  # noqa: E501
        :rtype: str
        """
        return self._seasonality

    @seasonality.setter
    def seasonality(self, seasonality):
        """Sets the seasonality of this RuleSchemaFormulaPredict.

        Seasonality. Should be of pattern [1-9][0-9]*(minutes|hours|days|weeks|months)(,[1-9][0-9]*(minutes|hours|days|weeks|months))*  # noqa: E501

        :param seasonality: The seasonality of this RuleSchemaFormulaPredict.  # noqa: E501
        :type: str
        """
        if seasonality is not None and not re.search(r'^[1-9][0-9]*(minutes|hours|days|weeks|months|t|h|d|w|m|T|H|D|W|M)(,[1-9][0-9]*(minutes|hours|days|weeks|months|t|h|d|w|m|T|H|D|W|M))*$', seasonality):  # noqa: E501
            raise ValueError(r"Invalid value for `seasonality`, must be a follow pattern or equal to `/^[1-9][0-9]*(minutes|hours|days|weeks|months|t|h|d|w|m|T|H|D|W|M)(,[1-9][0-9]*(minutes|hours|days|weeks|months|t|h|d|w|m|T|H|D|W|M))*$/`")  # noqa: E501

        self._seasonality = seasonality

    @property
    def prediction_offset(self):
        """Gets the prediction_offset of this RuleSchemaFormulaPredict.  # noqa: E501

        Time offset in future to predict. Should be of pattern [1-9][0-9]*(\\.[0-9]+)?(offset|seconds|minutes|hours|days|weeks|years|o|s|m|h|d|w|y)  # noqa: E501

        :return: The prediction_offset of this RuleSchemaFormulaPredict.  # noqa: E501
        :rtype: str
        """
        return self._prediction_offset

    @prediction_offset.setter
    def prediction_offset(self, prediction_offset):
        """Sets the prediction_offset of this RuleSchemaFormulaPredict.

        Time offset in future to predict. Should be of pattern [1-9][0-9]*(\\.[0-9]+)?(offset|seconds|minutes|hours|days|weeks|years|o|s|m|h|d|w|y)  # noqa: E501

        :param prediction_offset: The prediction_offset of this RuleSchemaFormulaPredict.  # noqa: E501
        :type: str
        """
        if prediction_offset is None:
            raise ValueError("Invalid value for `prediction_offset`, must not be `None`")  # noqa: E501
        if prediction_offset is not None and not re.search(r'^[1-9][0-9]*(\\.[0-9]+)?(offset|seconds|minutes|hours|days|weeks|years|o|s|m|h|d|w|y)$', prediction_offset):  # noqa: E501
            raise ValueError(r"Invalid value for `prediction_offset`, must be a follow pattern or equal to `/^[1-9][0-9]*(\\.[0-9]+)?(offset|seconds|minutes|hours|days|weeks|years|o|s|m|h|d|w|y)$/`")  # noqa: E501

        self._prediction_offset = prediction_offset

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RuleSchemaFormulaPredict, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RuleSchemaFormulaPredict):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
